@@ -101,7 +101,7 @@ static void layer_surface_handle_configure(
 static void layer_surface_handle_closed(void* data, struct zwlr_layer_surface_v1* _surface) {
     (void)_surface;
     struct layer_surface_t* self = data;
-    if (self->super.xdg_toplevel) {
+    if (self->respect_close && self->super.xdg_toplevel) {
         LIBWAYLAND_SHIM_DISPATCH_CLIENT_EVENT(xdg_toplevel_listener, close, self->super.xdg_toplevel);
     }
 }
@@ -384,6 +384,10 @@ void layer_surface_invalidate_preferred_size(struct layer_surface_t* self) {
     layer_surface_configure_xdg_surface(self, 0, false);
 }
 
+void layer_surface_set_respect_close(struct layer_surface_t* self, bool respect_close) {
+    self->respect_close = respect_close;
+}
+
 static bool xdg_wm_base_get_xdg_surface_hook(
     void* data,
     struct wl_proxy* proxy,
