@@ -10,4 +10,4 @@ env = {
     'GI_TYPELIB_PATH': src_build_dir,
     'LD_LIBRARY_PATH': src_build_dir,
 }
-smoke_test_common.run(['python3', script_path], env)
+smoke_test_common.run(['python3', script_path], 'layer', env)
